@@ -3,17 +3,16 @@
 
 from __future__ import annotations
 
-from typing import Callable, Optional, Union, Dict, Any, Tuple, Union, cast, List, Sequence, TypeVar
+from typing import Tuple, Union
 
 import torch
 from torch import Tensor
 from torch.distributions import Distribution
 
-from sbi.inference.posterior import NeuralPosterior
-
-from sbi.utils.metrics import c2st
-
+from sbi.inference.posteriors.base_posterior import NeuralPosterior
+from sbi.inference.posteriors.direct_posterior import DirectPosterior
 from sbi.simulators.linear_gaussian import true_posterior_linear_gaussian_mvn_prior
+from sbi.utils.metrics import c2st
 
 
 def kl_d_via_monte_carlo(
@@ -99,7 +98,7 @@ def get_prob_outside_uniform_prior(posterior: NeuralPosterior, num_dim: int) ->
 
 
 def get_normalization_uniform_prior(
-    posterior: NeuralPosterior, prior: Distribution, true_observation: Tensor,
+    posterior: DirectPosterior, prior: Distribution, true_observation: Tensor,
 ) -> Tuple[Tensor, Tensor, Tensor]:
     """
     Return the unnormalized posterior likelihood, the normalized posterior likelihood,
@@ -116,12 +115,12 @@ def get_normalization_uniform_prior(
 
     # Compute unnormalized density, i.e. just the output of the density estimator.
     posterior_likelihood_unnorm = torch.exp(
-        posterior.log_prob(prior_sample, norm_posterior_snpe=False)
+        posterior.log_prob(prior_sample, norm_posterior=False)
     )
     # Compute the normalized density, scale up output of the density
     # estimator by the ratio of posterior samples within the prior bounds.
     posterior_likelihood_norm = torch.exp(
-        posterior.log_prob(prior_sample, norm_posterior_snpe=True)
+        posterior.log_prob(prior_sample, norm_posterior=True)
     )
 
     # Estimate acceptance ratio through rejection sampling.
